pub struct Op { /* private fields */ }Expand description
Op is the Rc wrapper of typed op trait
Implementations
Read the input, do the calculation and write result to output. Called by compute_grapyh.
pub struct Op { /* private fields */ }Op is the Rc wrapper of typed op trait
Read the input, do the calculation and write result to output. Called by compute_grapyh.